import { AfterViewInit, ElementRef } from '@angular/core';
/**
 * Removes excess text from element until it fits in elements
 * and appends a ellipsis symbol to end of text. This requires that
 * the elements height be fixed and it's `overflow` css property
 * be `hidden`
 *
 * @example
 * ```html
 * <p snEllipsis>Ullamco esse laborum</p>
 * ```
 *
 */
export declare class EllipsisDirective implements AfterViewInit {
    private el;
    private platformId;
    /**
     * Ellipsis charater
     *
     * @memberof EllipsisDirective
     */
    private ellipsisChar;
    /**
     * If true means the elements contents are larger
     * than the size of the element.
     *
     * @memberof EllipsisDirective
     */
    private readonly hasOverflow;
    /**
     * Creates an instance of EllipsisDirective.
     *
     * @memberof EllipsisDirective
     */
    constructor(el: ElementRef, platformId: any);
    /**
     * Clip text on component initialisation
     *
     * @memberof EllipsisDirective
     */
    ngAfterViewInit(): void;
    /**
     * Removes character from end of `innerText`
     * until text fits in element and appends
     * a ellipsis symbol to the end.
     *
     * @memberof EllipsisDirective
     */
    private clipText;
}
