import { Directive, ElementRef, Inject, PLATFORM_ID, NgModule } from '@angular/core';
import { isPlatformBrowser } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Removes excess text from element until it fits in elements
 * and appends a ellipsis symbol to end of text. This requires that
 * the elements height be fixed and it's `overflow` css property
 * be `hidden`
 *
 * \@example
 * ```html
 * <p snEllipsis>Ullamco esse laborum</p>
 * ```
 *
 */
class EllipsisDirective {
    /**
     * Creates an instance of EllipsisDirective.
     *
     * \@memberof EllipsisDirective
     * @param {?} el
     * @param {?} platformId
     */
    constructor(el, platformId) {
        this.el = el;
        this.platformId = platformId;
        /**
         * Ellipsis charater
         *
         * \@memberof EllipsisDirective
         */
        this.ellipsisChar = '…';
    }
    /**
     * If true means the elements contents are larger
     * than the size of the element.
     *
     * \@memberof EllipsisDirective
     * @private
     * @return {?}
     */
    get hasOverflow() {
        /** @type {?} */
        const el = this.el.nativeElement;
        return el.scrollHeight > el.offsetHeight;
    }
    /**
     * Clip text on component initialisation
     *
     * \@memberof EllipsisDirective
     * @return {?}
     */
    ngAfterViewInit() {
        /** @type {?} */
        const isBrowser = isPlatformBrowser(this.platformId);
        if (isBrowser) {
            this.clipText();
        }
    }
    /**
     * Removes character from end of `innerText`
     * until text fits in element and appends
     * a ellipsis symbol to the end.
     *
     * \@memberof EllipsisDirective
     * @private
     * @return {?}
     */
    clipText() {
        /** @type {?} */
        const el = this.el.nativeElement;
        /** @type {?} */
        let text = el.innerText.split(' ');
        while (this.hasOverflow && text.length > 0) {
            text = text.slice(0, -1);
            el.innerText = `${text.join(' ')}${this.ellipsisChar}`;
        }
    }
}
EllipsisDirective.decorators = [
    { type: Directive, args: [{
                selector: '[snEllipsis]',
            },] }
];
/** @nocollapse */
EllipsisDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: undefined, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * A simple lightweight library for Angular which removes excess text
 * and adds an ellipsis symbol to end of text before text overflows container
 *
 */
class EllipsisModule {
}
EllipsisModule.decorators = [
    { type: NgModule, args: [{
                declarations: [EllipsisDirective],
                exports: [EllipsisDirective],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { EllipsisModule, EllipsisDirective };

//# sourceMappingURL=thisissoon-angular-ellipsis.js.map