import { Directive, ElementRef, Inject, PLATFORM_ID, NgModule } from '@angular/core';
import { isPlatformBrowser } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Removes excess text from element until it fits in elements
 * and appends a ellipsis symbol to end of text. This requires that
 * the elements height be fixed and it's `overflow` css property
 * be `hidden`
 *
 * \@example
 * ```html
 * <p snEllipsis>Ullamco esse laborum</p>
 * ```
 *
 */
var EllipsisDirective = /** @class */ (function () {
    /**
     * Creates an instance of EllipsisDirective.
     *
     * @memberof EllipsisDirective
     */
    function EllipsisDirective(el, platformId) {
        this.el = el;
        this.platformId = platformId;
        /**
         * Ellipsis charater
         *
         * \@memberof EllipsisDirective
         */
        this.ellipsisChar = '…';
    }
    Object.defineProperty(EllipsisDirective.prototype, "hasOverflow", {
        /**
         * If true means the elements contents are larger
         * than the size of the element.
         *
         * @memberof EllipsisDirective
         */
        get: /**
         * If true means the elements contents are larger
         * than the size of the element.
         *
         * \@memberof EllipsisDirective
         * @private
         * @return {?}
         */
        function () {
            /** @type {?} */
            var el = this.el.nativeElement;
            return el.scrollHeight > el.offsetHeight;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Clip text on component initialisation
     *
     * @memberof EllipsisDirective
     */
    /**
     * Clip text on component initialisation
     *
     * \@memberof EllipsisDirective
     * @return {?}
     */
    EllipsisDirective.prototype.ngAfterViewInit = /**
     * Clip text on component initialisation
     *
     * \@memberof EllipsisDirective
     * @return {?}
     */
    function () {
        /** @type {?} */
        var isBrowser = isPlatformBrowser(this.platformId);
        if (isBrowser) {
            this.clipText();
        }
    };
    /**
     * Removes character from end of `innerText`
     * until text fits in element and appends
     * a ellipsis symbol to the end.
     *
     * @memberof EllipsisDirective
     */
    /**
     * Removes character from end of `innerText`
     * until text fits in element and appends
     * a ellipsis symbol to the end.
     *
     * \@memberof EllipsisDirective
     * @private
     * @return {?}
     */
    EllipsisDirective.prototype.clipText = /**
     * Removes character from end of `innerText`
     * until text fits in element and appends
     * a ellipsis symbol to the end.
     *
     * \@memberof EllipsisDirective
     * @private
     * @return {?}
     */
    function () {
        /** @type {?} */
        var el = this.el.nativeElement;
        /** @type {?} */
        var text = el.innerText.split(' ');
        while (this.hasOverflow && text.length > 0) {
            text = text.slice(0, -1);
            el.innerText = "" + text.join(' ') + this.ellipsisChar;
        }
    };
    EllipsisDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[snEllipsis]',
                },] }
    ];
    /** @nocollapse */
    EllipsisDirective.ctorParameters = function () { return [
        { type: ElementRef },
        { type: undefined, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] }
    ]; };
    return EllipsisDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * A simple lightweight library for Angular which removes excess text
 * and adds an ellipsis symbol to end of text before text overflows container
 *
 */
var EllipsisModule = /** @class */ (function () {
    function EllipsisModule() {
    }
    EllipsisModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [EllipsisDirective],
                    exports: [EllipsisDirective],
                },] }
    ];
    return EllipsisModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { EllipsisModule, EllipsisDirective };

//# sourceMappingURL=thisissoon-angular-ellipsis.js.map